SET SESSION FOREIGN_KEY_CHECKS=0;


/* Create Tables */

DROP TABLE IF EXISTS GESTION;
DROP TABLE IF EXISTS PIEZAS;
DROP TABLE IF EXISTS PROVEEDORES;
DROP TABLE IF EXISTS PROYECTOS;
DROP TABLE IF EXISTS ZONAS;

CREATE TABLE GESTION
(
	CODPROVEEDOR varchar(6) NOT NULL,
	CODPIEZA varchar(6) NOT NULL,
	CODPROYECTO varchar(6) NOT NULL,
	CANTIDAD INT(5),
	CONSTRAINT SYS_C009466 PRIMARY KEY (CODPROVEEDOR, CODPIEZA, CODPROYECTO)
);


CREATE TABLE PIEZAS
(
	CODIGO varchar(6) NOT NULL,
	NOMBRE varchar(20) NOT NULL,
	PRECIO decimal(7,2) NOT NULL,
	DESCRIPCION varchar(100),
	STOCK INT(5),
	CONSTRAINT SYS_C009455 PRIMARY KEY (CODIGO)
);


CREATE TABLE PROVEEDORES
(
	CODIGO varchar(6) NOT NULL,
	NOMBRE varchar(20) NOT NULL,
	APELLIDOS varchar(30) NOT NULL,
	DIRECCION varchar(40) NOT NULL,
	COMISION decimal(5,1),
	CONSTRAINT SYS_C009460 PRIMARY KEY (CODIGO)
);


CREATE TABLE PROYECTOS
(
	CODIGO varchar(6) NOT NULL,
	NOMBRE varchar(40) NOT NULL,
	CIUDAD varchar(40),
	PRESUPUESTO decimal(6,0),
	CODZONA int(4) ,
	CONSTRAINT SYS_C009463 PRIMARY KEY (CODIGO)
);

CREATE TABLE ZONAS
(
	CODIGO int(4) NOT NULL,
	NOMBRE varchar(15) NOT NULL,
	TASA decimal(6,2),
	CONSTRAINT SYS_C009461 PRIMARY KEY (CODIGO)
);


/* Create Foreign Keys */

ALTER TABLE GESTION
	ADD CONSTRAINT SYS_C009468 FOREIGN KEY (CODPIEZA)
	REFERENCES PIEZAS (CODIGO)
	ON UPDATE CASCADE
	ON DELETE RESTRICT
;


ALTER TABLE GESTION
	ADD CONSTRAINT SYS_C009467 FOREIGN KEY (CODPROVEEDOR)
	REFERENCES PROVEEDORES (CODIGO)
	ON UPDATE CASCADE
	ON DELETE RESTRICT
;


ALTER TABLE GESTION
	ADD CONSTRAINT SYS_C009469 FOREIGN KEY (CODPROYECTO)
	REFERENCES PROYECTOS (CODIGO)
	ON UPDATE CASCADE
	ON DELETE RESTRICT
;

ALTER TABLE PROYECTOS
	ADD CONSTRAINT SYS_C009470 FOREIGN KEY (CODZONA)
	REFERENCES ZONAS (CODIGO)
	ON UPDATE CASCADE
	ON DELETE RESTRICT
;


/* Create Indexes */

CREATE UNIQUE INDEX SYS_C009466 ON GESTION (CODPROVEEDOR ASC, CODPIEZA ASC, CODPROYECTO ASC);

/* --  INSERTAR EN TABLAS */

INSERT INTO PIEZAS VALUES('P0001','CAUDALIMETRO', 400.32, 'PARA LOS VEHICULOS DIESEL',10);
INSERT INTO PIEZAS VALUES('P0002','CORREA DENTADA', 40, 'FACIL DE COLOCAR',5);
INSERT INTO PIEZAS VALUES('P0004','RODILLO TENSOR', 31, 'MONTAJE Y DESMONTAJE FACIL',15);
INSERT INTO PIEZAS VALUES('L0001','LONA PARA PISCINA', 178,'DE COLOR VERDE PARA TODO TIPO DE PISCINAS',2);
INSERT INTO PIEZAS VALUES('L0002','HORMIGONERA', 600.75, 'PARA REMOVER TODO TIPO DE CEMENTO',10);

INSERT INTO PIEZAS VALUES('P0005','FRENOS DE DISCO', 470.32, 'DE ACERO INOXIDABLE, DE CARBONO Y DE CERMICA',9);
INSERT INTO PIEZAS VALUES('P0006','FRENOS DE TAMBOR', 500, 'REVISAR LQUIDO DE FRENO',15);
INSERT INTO PIEZAS VALUES('P0007','ENGANCHE', 50, 'CON RTULA, HERRAJE Y PERNOS',16);
INSERT INTO PIEZAS VALUES('L0003','BACA-PORTABICIS', 230,'SUJECIN CON PUNTOS DE ANCLAJE',20);
INSERT INTO PIEZAS VALUES('L0004','RETROVISOR', 50, 'ADAPTABLE A VARIAS MARCAS',10);

INSERT INTO PIEZAS VALUES('L0005','EMBRAGUE', 450, 'ADAPTABLE AL MODELO',15);
INSERT INTO PIEZAS VALUES('L0006','ELEVALUNAS', 350, 'ADAPTABLE A VARIAS MARCAS',21);

INSERT INTO PIEZAS VALUES('L0007','FRENOS BICICLETA', 25, 'ADAPTABLE A VARIAS MARCAS',12);

INSERT INTO PIEZAS VALUES('L0008','ASIENTOS ABATIBLES', 100, 'ADAPTABLE SEGN MODELO',13);

/* -- --------------- */

INSERT INTO PROVEEDORES VALUES('PR0001','JUAN', 'VALDES', 'POLIGONO LA CAFETERA 55, GUADALAJARA',1000);
INSERT INTO PROVEEDORES VALUES('PR0002','GREGORIA', 'JIMENEZ', 'LA HERRERIA 27, TOLEDO',1200);
INSERT INTO PROVEEDORES VALUES('PR0003','MANUEL', 'PIMENTEL', 'SAN FRANCISCO 18, SEVILLA',2000);
INSERT INTO PROVEEDORES VALUES('PR0004','ALICIA', 'GARCA', 'LOS ALFARES 5, TOLEDO',1500);
INSERT INTO PROVEEDORES VALUES('PR0005','MARA', 'GAMA', 'OROPESA 15, TOLEDO',1000);

/* -- ---------------------- */

INSERT INTO zonas VALUES(1,'CENTRO', 1200.5);
INSERT INTO ZONAS VALUES(2,'CENTRO-ESTE', 2300.5);
INSERT INTO ZONAS VALUES(3,'NORTE',2000);
INSERT INTO ZONAS VALUES(4,'OESTE',1400);
INSERT INTO ZONAS VALUES(5,'LEVANTE',1200);
INSERT INTO ZONAS VALUES(6,'CATALUA',2500);
INSERT INTO ZONAS VALUES(7,'CANTBRICO',1500.5);

 /* -- --------------------------  */
INSERT INTO PROYECTOS VALUES('CR0001','CASA RURAL EL ALTOZANO', 'BERROCALEJO',30000,4);
INSERT INTO PROYECTOS VALUES('VH0011','VEHICULO PROTOTIPO', 'CACERES',23000,4);
INSERT INTO PROYECTOS VALUES('ED0001','EDIFICIO VIVIENDAS', 'TOLEDO',20000,1);
INSERT INTO PROYECTOS VALUES('ED0002','COLEGIO RURAL', 'BARCELONA',35000,6);

/* --------------------------------------------------- */


INSERT INTO GESTION VALUES('PR0001', 'L0002','ED0001', 10);
INSERT INTO GESTION VALUES('PR0001', 'L0003','ED0001', 10);
INSERT INTO GESTION VALUES('PR0001', 'L0004','ED0001', 10);
INSERT INTO GESTION VALUES('PR0001', 'P0007','ED0001', 10);

INSERT INTO GESTION VALUES('PR0001', 'P0001','VH0011', 24);
INSERT INTO GESTION VALUES('PR0001', 'P0002','VH0011', 25);
INSERT INTO GESTION VALUES('PR0001', 'P0007','VH0011', 10);


INSERT INTO GESTION VALUES('PR0002', 'L0001','CR0001', 15);
INSERT INTO GESTION VALUES('PR0002', 'P0004','CR0001', 15);
INSERT INTO GESTION VALUES('PR0002', 'P0005','CR0001', 3);
INSERT INTO GESTION VALUES('PR0002', 'P0006','CR0001', 10);
INSERT INTO GESTION VALUES('PR0002', 'P0007','CR0001', 10);

INSERT INTO GESTION VALUES('PR0002', 'P0005','ED0001', 3);
INSERT INTO GESTION VALUES('PR0002', 'P0006','ED0001', 2);
INSERT INTO GESTION VALUES('PR0002', 'P0007','ED0001', 20);

INSERT INTO GESTION VALUES('PR0002', 'P0007','VH0011', 12);
INSERT INTO GESTION VALUES('PR0002', 'L0002','VH0011', 12);

INSERT INTO GESTION VALUES('PR0003', 'L0003','CR0001', 3);
INSERT INTO GESTION VALUES('PR0003', 'L0004','CR0001', 5);
INSERT INTO GESTION VALUES('PR0003', 'P0004','CR0001',5);
INSERT INTO GESTION VALUES('PR0003', 'P0005','CR0001', 3);
INSERT INTO GESTION VALUES('PR0003', 'P0007','CR0001', 10);

INSERT INTO GESTION VALUES('PR0004', 'L0007','CR0001', 3);
INSERT INTO GESTION VALUES('PR0004', 'L0001','CR0001', 15);
INSERT INTO GESTION VALUES('PR0004', 'P0004','CR0001', 15);
INSERT INTO GESTION VALUES('PR0004', 'P0005','CR0001', 3);
INSERT INTO GESTION VALUES('PR0004', 'P0006','CR0001', 10);


INSERT INTO GESTION VALUES('PR0004', 'P0001','ED0001', 5);
INSERT INTO GESTION VALUES('PR0004', 'P0002','ED0001', 5);
INSERT INTO GESTION VALUES('PR0004', 'P0007','ED0001', 5);


INSERT INTO GESTION VALUES('PR0004', 'P0001','VH0011', 5);
INSERT INTO GESTION VALUES('PR0004', 'P0002','VH0011', 5);
INSERT INTO GESTION VALUES('PR0004', 'P0004','VH0011', 5);
INSERT INTO GESTION VALUES('PR0004', 'P0005','VH0011', 5);
INSERT INTO GESTION VALUES('PR0004', 'P0006','VH0011', 5);
INSERT INTO GESTION VALUES('PR0004', 'P0007','VH0011', 5);

INSERT INTO GESTION VALUES('PR0003', 'L0007','ED0002', 5);
INSERT INTO GESTION VALUES('PR0003', 'L0006','ED0002', 5);
INSERT INTO GESTION VALUES('PR0003', 'L0004','ED0002', 5);




